@@ -2,7 +2,7 @@ import unittest
 import random
 import subprocess
 import os
-from commontest import abs_test_dir
+from commontest import abs_test_dir, os_system
 from rdiff_backup import Globals, librsync, rpath
 
 
@@ -10,13 +10,8 @@ def MakeRandomFile(path, length=None):
     """Writes a random file of given length, or random len if unspecified"""
     if not length:
         length = random.randrange(5000, 100000)
-    fp = open(path, "wb")
-    fp_random = open('/dev/urandom', 'rb')
-
-    fp.write(fp_random.read(length))
-
-    fp.close()
-    fp_random.close()
+    with open(path, "wb") as fp:
+        fp.write(os.urandom(length))
 
 
 class LibrsyncTest(unittest.TestCase):
@@ -35,17 +30,17 @@ class LibrsyncTest(unittest.TestCase):
             self._clean_file(self.sig)
             rdiff_help_text = subprocess.check_output(["rdiff", "--help"])
             if b'-R' in rdiff_help_text:
-                assert not os.system(
+                self.assertEqual(os_system(
                     b"rdiff -b %i -R rollsum -S 8 -H md4 signature %b %b" %
-                    (blocksize, self.basis.path, self.sig.path))
+                    (blocksize, self.basis.path, self.sig.path)), 0)
             elif b'-H' in rdiff_help_text:
-                assert not os.system(
+                self.assertEqual(os_system(
                     b"rdiff -b %i -H md4 signature %b %b" %
-                    (blocksize, self.basis.path, self.sig.path))
+                    (blocksize, self.basis.path, self.sig.path)), 0)
             else:
-                assert not os.system(
+                self.assertEqual(os_system(
                     b"rdiff -b %i signature %b %b" %
-                    (blocksize, self.basis.path, self.sig.path))
+                    (blocksize, self.basis.path, self.sig.path)), 0)
             with self.sig.open("rb") as fp:
                 rdiff_sig = fp.read()
 
@@ -53,8 +48,7 @@ class LibrsyncTest(unittest.TestCase):
             librsync_sig = sf.read()
             sf.close()
 
-            assert rdiff_sig == librsync_sig, \
-                (len(rdiff_sig), len(librsync_sig))
+            self.assertEqual(rdiff_sig, librsync_sig)
 
     def _clean_file(self, rp):
         """Make sure the given rpath is properly cleaned"""
@@ -88,21 +82,20 @@ class LibrsyncTest(unittest.TestCase):
                     if not buf:
                         break
                     sig_gen.update(buf)
-                siggen_string = sig_gen.getsig()
+                siggen_string = sig_gen.get_sig()
 
-            assert sigfile_string == siggen_string, \
-                (len(sigfile_string), len(siggen_string))
+            self.assertEqual(sigfile_string, siggen_string)
 
     def OldtestDelta(self):
         """Test delta generation against Rdiff"""
         MakeRandomFile(self.basis.path)
-        assert not os.system(b"rdiff signature %s %s" %
-                             (self.basis.path, self.sig.path))
+        self.assertEqual(os_system(
+            b"rdiff signature %s %s" % (self.basis.path, self.sig.path)), 0)
         for i in range(5):
             MakeRandomFile(self.new.path)
-            assert not os.system(
+            self.assertEqual(os_system(
                 b"rdiff delta %b %b %b" %
-                (self.sig.path, self.new.path, self.delta.path))
+                (self.sig.path, self.new.path, self.delta.path)), 0)
             fp = self.delta.open("rb")
             rdiff_delta = fp.read()
             fp.close()
@@ -114,7 +107,7 @@ class LibrsyncTest(unittest.TestCase):
             print(len(rdiff_delta), len(librsync_delta))
             print(repr(rdiff_delta[:100]))
             print(repr(librsync_delta[:100]))
-            assert rdiff_delta == librsync_delta
+            self.assertEqual(rdiff_delta, librsync_delta)
 
     def testDelta(self):
         """Test delta generation by making sure rdiff can process output
@@ -125,8 +118,8 @@ class LibrsyncTest(unittest.TestCase):
         """
         MakeRandomFile(self.basis.path)
         self._clean_file(self.sig)
-        assert not os.system(b"rdiff signature %s %s" %
-                             (self.basis.path, self.sig.path))
+        self.assertEqual(os_system(
+            b"rdiff signature %s %s" % (self.basis.path, self.sig.path)), 0)
         for i in range(5):
             MakeRandomFile(self.new.path)
             df = librsync.DeltaFile(self.sig.open("rb"), self.new.open("rb"))
@@ -137,9 +130,9 @@ class LibrsyncTest(unittest.TestCase):
             fp.close()
 
             self._clean_file(self.new2)
-            assert not os.system(
+            self.assertEqual(os_system(
                 b"rdiff patch %s %s %s" %
-                (self.basis.path, self.delta.path, self.new2.path))
+                (self.basis.path, self.delta.path, self.new2.path)), 0)
             new_fp = self.new.open("rb")
             new = new_fp.read()
             new_fp.close()
@@ -148,20 +141,20 @@ class LibrsyncTest(unittest.TestCase):
             new2 = new2_fp.read()
             new2_fp.close()
 
-            assert new == new2, (len(new), len(new2))
+            self.assertEqual(new, new2)
 
     def testPatch(self):
         """Test patching against Rdiff"""
         MakeRandomFile(self.basis.path)
         self._clean_file(self.sig)
-        assert not os.system(b"rdiff signature %s %s" %
-                             (self.basis.path, self.sig.path))
+        self.assertEqual(os_system(
+            b"rdiff signature %s %s" % (self.basis.path, self.sig.path)), 0)
         for i in range(5):
             MakeRandomFile(self.new.path)
             self._clean_file(self.delta)
-            assert not os.system(
+            self.assertEqual(os_system(
                 b"rdiff delta %s %s %s" %
-                (self.sig.path, self.new.path, self.delta.path))
+                (self.sig.path, self.new.path, self.delta.path)), 0)
             fp = self.new.open("rb")
             real_new = fp.read()
             fp.close()
@@ -171,8 +164,7 @@ class LibrsyncTest(unittest.TestCase):
             librsync_new = pf.read()
             pf.close()
 
-            assert real_new == librsync_new, \
-                (len(real_new), len(librsync_new))
+            self.assertEqual(real_new, librsync_new)
 
 
 if __name__ == "__main__":
