@@ -4,7 +4,7 @@ import sys
 import unittest
 import time
 from commontest import old_test_dir, abs_test_dir, re_init_subdir, abs_output_dir, \
-    re_init_rpath_dir
+    re_init_rpath_dir, os_system
 from rdiff_backup import Globals, rpath
 
 
@@ -22,10 +22,11 @@ class RORPStateTest(RPathTest):
     def testPickle(self):
         rorp = rpath.RPath(self.lc, self.prefix, ("regular_file", )).getRORPath()
         rorp.file = sys.stdin  # try to confuse pickler
-        assert rorp.isreg()
+        self.assertTrue(rorp.isreg())
         rorp2 = pickle.loads(pickle.dumps(rorp, 1))
-        assert rorp2.isreg()
-        assert rorp2.data == rorp.data and rorp.index == rorp2.index
+        self.assertTrue(rorp2.isreg())
+        self.assertEqual(rorp2.data, rorp.data)
+        self.assertEqual(rorp2.index, rorp.index)
 
 
 class CheckTypes(RPathTest):
@@ -33,34 +34,40 @@ class CheckTypes(RPathTest):
 
     def testExist(self):
         """Can tell if files exist"""
-        assert rpath.RPath(self.lc, self.prefix, ()).lstat()
-        assert not rpath.RPath(self.lc, "asuthasetuouo", ()).lstat()
+        self.assertTrue(rpath.RPath(self.lc, self.prefix, ()).lstat())
+        self.assertFalse(rpath.RPath(self.lc, "asuthasetuouo", ()).lstat())
 
     def testDir(self):
         """Directories identified correctly"""
-        assert rpath.RPath(self.lc, self.prefix, ()).isdir()
-        assert not rpath.RPath(self.lc, self.prefix, ("regular_file", )).isdir()
+        self.assertTrue(rpath.RPath(self.lc, self.prefix, ()).isdir())
+        self.assertFalse(
+            rpath.RPath(self.lc, self.prefix, ("regular_file", )).isdir())
 
     def testSym(self):
         """Symbolic links identified"""
-        assert rpath.RPath(self.lc, self.prefix, ("symbolic_link", )).issym()
-        assert not rpath.RPath(self.lc, self.prefix, ()).issym()
+        self.assertTrue(
+            rpath.RPath(self.lc, self.prefix, ("symbolic_link", )).issym())
+        self.assertFalse(rpath.RPath(self.lc, self.prefix, ()).issym())
 
     def testReg(self):
         """Regular files identified"""
-        assert rpath.RPath(self.lc, self.prefix, ("regular_file", )).isreg()
-        assert not rpath.RPath(self.lc, self.prefix, ("symbolic_link", )).isreg()
+        self.assertTrue(
+            rpath.RPath(self.lc, self.prefix, ("regular_file", )).isreg())
+        self.assertFalse(
+            rpath.RPath(self.lc, self.prefix, ("symbolic_link", )).isreg())
 
+    @unittest.skipIf(os.name == "nt", "Fifo don't exist under Windows")
     def testFifo(self):
         """Fifo's identified"""
-        assert rpath.RPath(self.lc, self.prefix, ("fifo", )).isfifo()
-        assert not rpath.RPath(self.lc, self.prefix, ()).isfifo()
+        self.assertTrue(rpath.RPath(self.lc, self.prefix, ("fifo", )).isfifo())
+        self.assertFalse(rpath.RPath(self.lc, self.prefix, ()).isfifo())
 
     @unittest.skipUnless(os.path.exists('/dev/tty2'), "Test requires /dev/tty2")
     def testCharDev(self):
         """Char special files identified"""
-        assert rpath.RPath(self.lc, "/dev/tty2", ()).ischardev()
-        assert not rpath.RPath(self.lc, self.prefix, ("regular_file", )).ischardev()
+        self.assertTrue(rpath.RPath(self.lc, "/dev/tty2", ()).ischardev())
+        self.assertFalse(
+            rpath.RPath(self.lc, self.prefix, ("regular_file", )).ischardev())
 
     @unittest.skipUnless(
         os.path.exists('/dev/sda') or os.path.exists('/dev/nvme0n1'),
@@ -72,39 +79,42 @@ class CheckTypes(RPathTest):
         # somediskdev = os.path.realpath(psutil.disk_partitions()[0].device)
         # We assume that anybody must have a hard drive, SSD or NVMe
         if (os.path.exists('/dev/sda')):
-            assert rpath.RPath(self.lc, '/dev/sda', ()).isblkdev()
+            self.assertTrue(rpath.RPath(self.lc, '/dev/sda', ()).isblkdev())
         else:
-            assert rpath.RPath(self.lc, '/dev/nvme0n1', ()).isblkdev()
-        assert not rpath.RPath(self.lc, self.prefix, ("regular_file", )).isblkdev()
+            self.assertTrue(rpath.RPath(self.lc, '/dev/nvme0n1', ()).isblkdev())
+        self.assertFalse(
+            rpath.RPath(self.lc, self.prefix, ("regular_file", )).isblkdev())
 
 
+@unittest.skipIf(os.name == "nt", "Windows doesn't handle well rights")
 class CheckPerms(RPathTest):
     """Check to see if permissions are reported and set accurately"""
 
     def testExecReport(self):
         """Check permissions for executable files"""
-        assert self.rp_prefix.append('executable').getperms() == 0o755
-        assert self.rp_prefix.append('executable2').getperms() == 0o700
+        self.assertEqual(self.rp_prefix.append('executable').getperms(), 0o755)
+        self.assertEqual(self.rp_prefix.append('executable2').getperms(), 0o700)
 
     def testhighbits(self):
         """Test reporting of highbit permissions"""
         p = rpath.RPath(self.lc, os.path.join(self.mainprefix, b"rpath2",
                                               b"foobar")).getperms()
-        assert p == 0o4100, p
+        self.assertEqual(p, 0o4100)
 
     def testOrdinaryReport(self):
         """Ordinary file permissions..."""
-        assert self.rp_prefix.append("regular_file").getperms() == 0o644
-        assert self.rp_prefix.append(
-            'two_hardlinked_files1').getperms() == 0o640
+        self.assertEqual(
+            self.rp_prefix.append("regular_file").getperms(), 0o644)
+        self.assertEqual(
+            self.rp_prefix.append('two_hardlinked_files1').getperms(), 0o640)
 
     def testChmod(self):
         """Test changing file permission"""
         rp = self.rp_prefix.append("changeable_permission")
         rp.chmod(0o700)
-        assert rp.getperms() == 0o700
+        self.assertEqual(rp.getperms(), 0o700)
         rp.chmod(0o644)
-        assert rp.getperms() == 0o644
+        self.assertEqual(rp.getperms(), 0o644)
 
     def testExceptions(self):
         """What happens when file absent"""
@@ -122,10 +132,11 @@ class CheckTimes(RPathTest):
         rp.touch()
         rp.settime(10000, 20000)
         rp.setdata()
-        assert rp.getatime() == 10000
-        assert rp.getmtime() == 20000
+        self.assertEqual(rp.getatime(), 10000)
+        self.assertEqual(rp.getmtime(), 20000)
         rp.delete()
 
+    @unittest.skipIf(os.name == "nt", "Windows doesn't handle ctime correctly")
     def testCtime(self):
         """Check to see if ctime read, compared"""
         rp = rpath.RPath(self.lc, self.prefix, ("ctimetest.1", ))
@@ -133,14 +144,14 @@ class CheckTimes(RPathTest):
         rp.touch()
         rp.chmod(0o700)
         rpath.copy_with_attribs(rp, rp2)
-        assert rpath.cmp_attribs(rp, rp2)
+        self.assertTrue(rpath._cmp_file_attribs(rp, rp2))
 
         time.sleep(1)
         rp2.chmod(0o755)
         rp2.chmod(0o700)
         rp2.setdata()
-        assert rp2.getctime() > rp.getctime()
-        assert not rpath.cmp_attribs(rp, rp2)
+        self.assertGreater(rp2.getctime(), rp.getctime())
+        self.assertFalse(rpath._cmp_file_attribs(rp, rp2))
         rp.delete()
         rp2.delete()
 
@@ -151,11 +162,11 @@ class CheckDir(RPathTest):
     def testCreation(self):
         """Test directory creation and deletion"""
         d = self.rp_prefix.append("tempdir")
-        assert not d.lstat()
+        self.assertFalse(d.lstat())
         d.mkdir()
-        assert d.isdir()
+        self.assertTrue(d.isdir())
         d.rmdir()
-        assert not d.lstat()
+        self.assertFalse(d.lstat())
 
     def testExceptions(self):
         """Should raise os.errors when no files"""
@@ -167,61 +178,55 @@ class CheckDir(RPathTest):
 
     def testListdir(self):
         """Checking dir listings"""
-        dirlist = rpath.RPath(self.lc, self.mainprefix, ("sampledir", )).listdir()
+        dirlist = rpath.RPath(self.lc, self.mainprefix,
+                              ("sampledir", )).listdir()
         dirlist.sort()
-        assert dirlist == [b"1", b"2", b"3", b"4"], dirlist
+        self.assertEqual(dirlist, [b"1", b"2", b"3", b"4"])
 
 
+@unittest.skipIf(os.name == "nt", "Symlinks not supported under Windows")
 class CheckSyms(RPathTest):
     """Check symlinking and reading"""
 
     def testRead(self):
         """symlink read"""
-        assert (rpath.RPath(self.lc, self.prefix,
-                            ("symbolic_link", )).readlink() == b"regular_file")
+        self.assertEqual(
+            rpath.RPath(self.lc, self.prefix, ("symbolic_link", )).readlink(),
+            b"regular_file")
 
     def testMake(self):
         """Creating symlink"""
         link = rpath.RPath(self.lc, self.write_dir, ("symlink", ))
-        assert not link.lstat()
+        self.assertFalse(link.lstat())
         link.symlink("abcdefg")
-        assert link.issym()
-        assert link.readlink() == b"abcdefg"
+        self.assertTrue(link.issym())
+        self.assertEqual(link.readlink(), b"abcdefg")
         link.delete()
 
 
+@unittest.skipIf(os.name == "nt", "Sockets don't exist under Windows")
 class CheckSockets(RPathTest):
     """Check reading and making sockets"""
 
     def testMake(self):
         """Create socket, then read it"""
         sock = rpath.RPath(self.lc, self.write_dir, ("socket", ))
-        assert not sock.lstat()
+        self.assertFalse(sock.lstat())
         sock.mksock()
-        assert sock.issock()
+        self.assertTrue(sock.issock())
         sock.delete()
 
     def testLongSock(self):
-        """Test making a socket with a long name
-
-        On some systems, the name of a socket is restricted, and
-        cannot be as long as a regular file.  When this happens, a
-        SkipFileException should be raised.
-
-        """
+        """Test making a socket with a long name.
+        It shouldn't be an issue anymore on modern systems"""
         sock = rpath.RPath(self.lc, self.write_dir, (
             "socketaoeusthaoeaoeutnhaonseuhtansoeuthasoneuthasoeutnhasonuthaoensuhtasoneuhtsanouhonetuhasoneuthsaoenaonsetuaosenuhtaoensuhaoeu",
         ))
-        assert not sock.lstat()
-        try:
-            sock.mksock()
-        except rpath.SkipFileException:
-            pass
-        else:
-            print("Warning, making long socket did not fail")
+        self.assertFalse(sock.lstat())
+        sock.mksock()
         sock.setdata()
-        if sock.lstat():
-            sock.delete()
+        self.assertTrue(sock.lstat())
+        sock.delete()
 
 
 class TouchDelete(RPathTest):
@@ -230,18 +235,18 @@ class TouchDelete(RPathTest):
     def testTouch(self):
         """Creation of 0 length files"""
         t = rpath.RPath(self.lc, self.write_dir, ("testtouch", ))
-        assert not t.lstat()
+        self.assertFalse(t.lstat())
         t.touch()
-        assert t.lstat()
+        self.assertTrue(t.lstat())
         t.delete()
 
     def testDelete(self):
         """Deletion of files"""
         d = rpath.RPath(self.lc, self.write_dir, ("testdelete", ))
         d.touch()
-        assert d.lstat()
+        self.assertTrue(d.lstat())
         d.delete()
-        assert not d.lstat()
+        self.assertFalse(d.lstat())
 
 
 class MiscFileInfo(RPathTest):
@@ -249,19 +254,16 @@ class MiscFileInfo(RPathTest):
 
     def testFileLength(self):
         """File length = getsize()"""
-        assert (rpath.RPath(self.lc, self.prefix,
-                            ("regular_file", )).getsize() == 75650)
+        self.assertEqual(
+            rpath.RPath(self.lc, self.prefix, ("regular_file", )).getsize(),
+            75650)
 
 
 class FilenameOps(RPathTest):
     """Check filename operations"""
-    weirdfilename = eval(
-        '\'\\xd8\\xab\\xb1Wb\\xae\\xc5]\\x8a\\xbb\\x15v*\\xf4\\x0f!\\xf9>\\xe2Y\\x86\\xbb\\xab\\xdbp\\xb0\\x84\\x13k\\x1d\\xc2\\xf1\\xf5e\\xa5U\\x82\\x9aUV\\xa0\\xf4\\xdf4\\xba\\xfdX\\x03\\x82\\x07s\\xce\\x9e\\x8b\\xb34\\x04\\x9f\\x17 \\xf4\\x8f\\xa6\\xfa\\x97\\xab\\xd8\\xac\\xda\\x85\\xdcKvC\\xfa#\\x94\\x92\\x9e\\xc9\\xb7\\xc3_\\x0f\\x84g\\x9aB\\x11<=^\\xdbM\\x13\\x96c\\x8b\\xa7|*"\\\\\\\'^$@#!(){}?+ ~` \''
-    )
     normdict = {
         b"/": b"/",
         b".": b".",
-        b"//": b"/",
         b"/a/b": b"/a/b",
         b"a/b": b"a/b",
         b"a//b": b"a/b",
@@ -272,6 +274,8 @@ class FilenameOps(RPathTest):
         b"//host/share": b"//host/share",
         b"//host//share/": b"//host/share",
     }
+    if os.name != "nt":  # Windows doesn't like double slashes
+        normdict[b"//"] = b"/"
     dirsplitdict = {
         b"/": (b"", b""),
         b"/a": (b"", b"a"),
@@ -282,27 +286,17 @@ class FilenameOps(RPathTest):
         b"//host/share": (b"//host", b"share"),
     }
 
-    def testQuote(self):
-        """See if filename quoting works"""
-        wtf = rpath.RPath(self.lc, self.prefix, (self.weirdfilename, ))
-        reg = rpath.RPath(self.lc, self.prefix, (b"regular_file", ))
-        assert wtf.lstat()
-        assert reg.lstat()
-        assert not os.system(b"ls %s >/dev/null 2>&1" % wtf.quote())
-        assert not os.system(b"ls %s >/dev/null 2>&1" % reg.quote())
-
     def testNormalize(self):
         """rpath.normalize() dictionary test"""
         for (before, after) in list(self.normdict.items()):
-            assert rpath.RPath(self.lc, before, ()).normalize().path == after, \
-                "Normalize fails for %a => %a" % (before, after)
+            self.assertEqual(
+                rpath.RPath(self.lc, before, ()).normalize().path, after)
 
     def testDirsplit(self):
         """Test splitting of various directories"""
         for full, split in list(self.dirsplitdict.items()):
             result = rpath.RPath(self.lc, full, ()).dirsplit()
-            assert result == split, \
-                "%s => %s instead of %s" % (full, result, split)
+            self.assertEqual(result, split)
 
     @unittest.skipUnless(
         (os.path.exists('/dev/sda') or os.path.exists('/dev/nvme0n1'))
@@ -326,7 +320,7 @@ class FileIO(RPathTest):
     def testRead(self):
         """File reading"""
         with rpath.RPath(self.lc, self.prefix, ("executable", )).open("r") as fp:
-            assert fp.read(6) == "#!/bin"
+            self.assertEqual(fp.read(6), "#!/bin")
 
     def testWrite(self):
         """File writing"""
@@ -334,7 +328,7 @@ class FileIO(RPathTest):
         with rp.open("w") as fp:
             fp.write("hello")
         with rp.open("r") as fp_input:
-            assert fp_input.read() == "hello"
+            self.assertEqual(fp_input.read(), "hello")
         rp.delete()
 
     def testGzipWrite(self):
@@ -353,9 +347,14 @@ class FileIO(RPathTest):
 
         with rp_gz.open("wb", compress=1) as fp_out:
             fp_out.write(s)
-        assert not os.system(b"gunzip %s" % file_gz)
+        if os.name == "nt":
+            self.assertEqual(
+                os_system(b"7z x -o%s %s >NUL" % (abs_output_dir, file_gz)), 0)
+            os_system(b"del %s" % file_gz)
+        else:
+            self.assertEqual(os_system(b"gunzip %s" % file_gz), 0)
         with rp_nogz.open("rb") as fp_in:
-            assert fp_in.read() == s
+            self.assertEqual(fp_in.read(), s)
 
     def testGzipRead(self):
         """Test reading of gzipped files"""
@@ -374,17 +373,22 @@ class FileIO(RPathTest):
         with rp_nogz.open("w") as fp_out:
             fp_out.write(s)
         rp_nogz.setdata()
-        assert rp_nogz.lstat()
+        self.assertTrue(rp_nogz.lstat())
 
-        assert not os.system(b"gzip %s" % file_nogz)
+        if os.name == "nt":
+            self.assertEqual(
+                os_system(b"7z a -tgzip -sdel %s %s >NUL" % (file_gz,
+                                                             file_nogz)),
+                0)
+        else:
+            self.assertEqual(os_system(b"gzip %s" % file_nogz), 0)
         rp_nogz.setdata()
         rp_gz.setdata()
-        assert not rp_nogz.lstat()
-        assert rp_gz.lstat()
+        self.assertFalse(rp_nogz.lstat())
+        self.assertTrue(rp_gz.lstat())
         with rp_gz.open("r", compress=1) as fp_in:
             read_s = fp_in.read().decode()  # zip is always binary hence bytes
-            assert read_s == s, "Read string %s not like written %s." % (
-                read_s, s)
+            self.assertEqual(read_s, s)
 
 
 class FileCopying(RPathTest):
@@ -400,22 +404,24 @@ class FileCopying(RPathTest):
         self.dest = rpath.RPath(self.lc, self.mainprefix, ("dest", ))
         if self.dest.lstat():
             self.dest.delete()
-        assert not self.dest.lstat()
+        self.assertFalse(self.dest.lstat())
 
     def testComp(self):
         """Test comparisons involving regular files"""
-        assert rpath.cmp(self.hl1, self.hl2)
-        assert not rpath.cmp(self.rf, self.hl1)
-        assert not rpath.cmp(self.dir, self.rf)
+        self.assertTrue(rpath.cmp(self.hl1, self.hl2))
+        self.assertFalse(rpath.cmp(self.rf, self.hl1))
+        self.assertFalse(rpath.cmp(self.dir, self.rf))
 
+    @unittest.skipIf(os.name == "nt", "Symlinks not supported under Windows")
     def testCompMisc(self):
         """Test miscellaneous comparisons"""
-        assert rpath.cmp(self.dir, rpath.RPath(self.lc, self.mainprefix, ()))
+        self.assertTrue(
+            rpath.cmp(self.dir, rpath.RPath(self.lc, self.mainprefix, ())))
         self.dest.symlink("regular_file")
-        assert rpath.cmp(self.sl, self.dest)
+        self.assertTrue(rpath.cmp(self.sl, self.dest))
         self.dest.delete()
-        assert not rpath.cmp(self.sl, self.fifo)
-        assert not rpath.cmp(self.dir, self.sl)
+        self.assertFalse(rpath.cmp(self.sl, self.fifo))
+        self.assertFalse(rpath.cmp(self.dir, self.sl))
 
     def testDirSizeComp(self):
         """Make sure directories can be equal,
@@ -425,16 +431,20 @@ class FileCopying(RPathTest):
         bigdir = rpath.RPath(Globals.local_connection,
                              os.path.join(old_test_dir, b"dircomptest", b"2"))
         # Can guarantee below by adding files to bigdir
-        assert bigdir.getsize() > smalldir.getsize()
-        assert smalldir == bigdir
+        self.assertGreater(bigdir.getsize(), smalldir.getsize())
+        self.assertEqual(smalldir, bigdir)
 
     def testCopy(self):
         """Test copy of various files"""
-        for rp in [self.sl, self.rf, self.fifo, self.dir]:
+        if os.name == "nt":
+            comp_list = [self.rf, self.dir]
+        else:
+            comp_list = [self.sl, self.rf, self.fifo, self.dir]
+        for rp in comp_list:
             rpath.copy(rp, self.dest)
-            assert self.dest.lstat(), "%a doesn't exist" % self.dest.path
-            assert rpath.cmp(rp, self.dest)
-            assert rpath.cmp(self.dest, rp)
+            self.assertTrue(self.dest.lstat())
+            self.assertTrue(rpath.cmp(rp, self.dest))
+            self.assertTrue(rpath.cmp(self.dest, rp))
             self.dest.delete()
 
 
@@ -455,22 +465,22 @@ class FileAttributes(FileCopying):
         """Test attribute comparison success"""
         testpairs = [(self.hl1, self.hl2)]
         for a, b in testpairs:
-            assert a.equal_loose(b), "Err with %a %a" % (a.path, b.path)
-            assert b.equal_loose(a), "Err with %a %a" % (b.path, a.path)
+            self.assertTrue(a.equal_loose(b))
+            self.assertTrue(b.equal_loose(a))
 
     def testCompFail(self):
         """Test attribute comparison failures"""
         testpairs = [(self.nowrite, self.noperms), (self.exec1, self.exec2),
                      (self.rf, self.hl1)]
         for a, b in testpairs:
-            assert not a.equal_loose(b), "Err with %a %a" % (a.path, b.path)
-            assert not b.equal_loose(a), "Err with %a %a" % (b.path, a.path)
+            self.assertFalse(a.equal_loose(b))
+            self.assertFalse(b.equal_loose(a))
 
     def testCheckRaise(self):
         """Should raise exception when file missing"""
-        self.assertRaises(rpath.RPathException, rpath.check_for_files, self.nothing,
+        self.assertRaises(rpath.RPathException, rpath._check_for_files, self.nothing,
                           self.hl1)
-        self.assertRaises(rpath.RPathException, rpath.check_for_files, self.hl1,
+        self.assertRaises(rpath.RPathException, rpath._check_for_files, self.hl1,
                           self.nothing)
 
     def testCopyAttribs(self):
@@ -484,8 +494,7 @@ class FileAttributes(FileCopying):
         ]:
             rpath.copy(rp, t)
             rpath.copy_attribs(rp, t)
-            assert t.equal_loose(rp), \
-                "Attributes for file %s not copied successfully" % rp.path
+            self.assertTrue(t.equal_loose(rp))
             t.delete()
 
     def testCopyWithAttribs(self):
@@ -493,13 +502,14 @@ class FileAttributes(FileCopying):
         out = rpath.RPath(self.lc, self.write_dir, ("out", ))
         if out.lstat():
             out.delete()
-        for rp in [
-                self.noperms, self.nowrite, self.rf, self.exec1, self.exec2,
-                self.hl1, self.dir, self.sym
-        ]:
+        copy_list = [self.noperms, self.nowrite, self.rf,
+                     self.exec1, self.exec2, self.hl1, self.dir]
+        if os.name != "nt":  # symlinks not supported under Windows
+            copy_list.append(self.sym)
+        for rp in copy_list:
             rpath.copy_with_attribs(rp, out)
-            assert rpath.cmp(rp, out)
-            assert rp.equal_loose(out)
+            self.assertTrue(rpath.cmp(rp, out))
+            self.assertTrue(rp.equal_loose(out))
             out.delete()
 
     def testCopyRaise(self):
@@ -516,11 +526,11 @@ class CheckPath(unittest.TestCase):
     def testpath(self):
         """Test root paths"""
         root = rpath.RPath(Globals.local_connection, "/")
-        assert root.path == b"/", root.path
+        self.assertEqual(root.path, b"/")
         bin = root.append("bin")
-        assert bin.path == b"/bin", bin.path
+        self.assertEqual(bin.path, b"/bin")
         bin2 = rpath.RPath(Globals.local_connection, "/bin")
-        assert bin2.path == b"/bin", bin2.path
+        self.assertEqual(bin2.path, b"/bin")
 
 
 class Gzip(RPathTest):
@@ -535,21 +545,21 @@ class Gzip(RPathTest):
         fileobj = rpath.MaybeGzip(base_rp)
         fileobj.close()
         base_rp.setdata()
-        assert base_rp.isreg(), base_rp
-        assert base_rp.getsize() == 0
+        self.assertTrue(base_rp.isreg())
+        self.assertEqual(base_rp.getsize(), 0)
         base_rp.delete()
 
         base_gz = dirrp.append('foo.gz')
-        assert not base_gz.lstat()
+        self.assertFalse(base_gz.lstat())
         fileobj = rpath.MaybeGzip(base_rp)
         fileobj.write(b"lala")
         fileobj.close()
         base_rp.setdata()
         base_gz.setdata()
-        assert not base_rp.lstat()
-        assert base_gz.isreg(), base_gz
+        self.assertFalse(base_rp.lstat())
+        self.assertTrue(base_gz.isreg())
         data = base_gz.get_bytes(compressed=1)
-        assert data == b"lala", data
+        self.assertEqual(data, b"lala")
 
 
 if __name__ == "__main__":
